# Welcome to intellikit


[![image](https://img.shields.io/pypi/v/intellikit.svg)](https://pypi.python.org/pypi/intellikit)


**A python toolkit for case based reasoning, information retrieval, natural language processing and other techniques for AI and intelligent systems.**


-   Free software: MIT License
-   Documentation: <https://ArthurKakande.github.io/intellikit>
    

## Features

-   TODO
